@@ -286,7 +286,7 @@ class MarketAnalyzer:
         """
         return self.base * self.df / self.df.iloc[0, :].values
 
-    def plot_perf(self, title='Performances', ax=None, show=True, **kwargs):
+    def plot_perf(self, title='Performances', saving_png_path = None, ax=None, show=True, **kwargs):
         """ Plot asset performances.
 
         Parameters
@@ -311,6 +311,10 @@ class MarketAnalyzer:
         if not df.empty:
             df.plot(ax=ax, title=title, **kwargs)
 
+        if saving_png_path is not None:
+            plt.savefig(saving_png_path, format='png')
+
+
         if show:
             plt.show()
 
