@@ -28,6 +28,11 @@ class SignalParalleLauncher():
                     for signal_type, params  in signal_idiosyncratic_paramaters.items():
                         for param in params:
                             rand_hash= ''.join(random.choice(string.ascii_lowercase) for i in range(4))
+                            # problem due to json serialization
+                            rand_hash = rand_hash.replace('cc','wc')
+                            rand_hash = rand_hash.replace('dd','wd')
+                            rand_hash = rand_hash.replace('qq','wq')
+                            rand_hash = rand_hash.replace('aa','wa')
                             self.args.append((self,rand_hash,trigger,signal_type, json.dumps(param, sort_keys=True), transaction_cost, normalization))
                             self.key_args.append((rand_hash, trigger, signal_type, json.dumps(param, sort_keys=True),transaction_cost, normalization))
 
