@@ -92,7 +92,11 @@ class EnsemblingSignalRunner(AbstractRunner):
             else :
                 if self.add_turn_over:
                     raise Exception('to add turn over, you have to recompute all')
-                freqlyperf_df = self.precomputed_results_df[me_signal]
+                try:
+                    freqlyperf_df = self.precomputed_results_df[me_signal]
+                except KeyError:
+                    print('cannot read ', me_signal)
+                    continue
                 freqlysig_df = self.precomputed_signals_df[me_signal]
                 freqlyperf_df = freqlyperf_df.to_frame()
                 freqlyperf_df.columns = ['reconstituted_perf']
