@@ -10,6 +10,10 @@ from napoleontoolbox.signal import signal_utility
 from napoleontoolbox.connector import napoleon_connector
 import json
 
+from napoleontoolbox.parallel_run import signal_result_analyzer
+
+
+
 def unjsonize_list_run_results(local_root_directory, list_pkl_file_name):
     signals_list = napoleon_connector.load_pickled_list(local_root_directory=local_root_directory,
                                                              list_pkl_file_name=list_pkl_file_name)
@@ -123,6 +127,64 @@ def compute_signal_perf_ind(data=None, initial_price = 1. , average_execution_co
     perf_strat = (data['non_adjusted_reconstituted_perf'].iloc[-1] - 1.) / 1.
     return average_turn_over, perf_under, perf_strat
 
+def compute_signals_kpi(data=None, mapping_data=None, print_turnover = False, keep_only_one_per_signal_family = False):
+    hr_dic, json_dic = signal_result_analyzer.unjsonize_mapping_dataframe(mapping_data)
+    all_signals = [col for col in data.columns if 'signal' in col]
+    results_dic = {}
+    results_dic_df = {}
+    results_dic_without = {}
+    results_dic_without_df = {}
+    kpis = []
+    for sig in all_signals:
+        for transac_cost in [True, False]:
+            temp_df = data[['close', sig]].copy()
+            temp_df = temp_df.rename(columns={sig: "signal"}, errors="raise")
+            freqly_df = signal_utility.reconstitute_signal_perf(data=temp_df, transaction_cost=transac_cost,print_turnover=print_turnover)
+            sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period=252 * 24 * 60, from_ret=True)
+            sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period=252 * 24 * 60, from_ret=True)
+            kpis.append(
+                {
+                    'sharpe_under': sharpe_under,
+                    'sharpe_strat': sharpe_strat,
+                    'signal': sig,
+                    'transaction_cost': transac_cost,
+                    'parameters_hash': hr_dic[sig]
+                }
+            )
+            results_dic[sig + str(transac_cost)] = sharpe_strat
+            results_dic_df[sig + str(transac_cost)] = [sharpe_strat]
+            if not transac_cost:
+                results_dic_without[sig] = sharpe_strat
+                results_dic_without_df[sig] = [sharpe_strat]
+    kpis_df = pd.DataFrame(kpis)
+    single_kpis_df = kpis_df[['sharpe_under','sharpe_strat','transaction_cost']].copy().drop_duplicates()
+    kpis_df = kpis_df[kpis_df.index.isin(list(single_kpis_df.index))]
+    if keep_only_one_per_signal_family:
+        results_dic_df = pd.DataFrame(results_dic_df)
+        results_dic_without_df = pd.DataFrame(results_dic_without_df).T
+        results_dic_without_df.columns = ['sharpe']
+        results_dic_without_df = results_dic_without_df.sort_values(by=['sharpe'], ascending=False)
+        results_dic_without_df = results_dic_without_df.reset_index()
+
+        selected_algos = set()
+        signals_to_keep = []
+        for index, row in results_dic_without_df.iterrows():
+            me_signal = row['index']
+            print(me_signal)
+            print(row['sharpe'])
+            print(hr_dic[me_signal])
+            params = json_dic[me_signal]
+            if params['signal_type'] in selected_algos:
+                continue
+            else:
+                selected_algos.add(params['signal_type'])
+            signals_to_keep.append(me_signal)
+
+        me_signals_to_keep = results_dic_without_df['index'].apply(lambda x: x in signals_to_keep)
+        results_dic_without_df = results_dic_without_df.loc[me_signals_to_keep]
+        kpis_df =kpis_df[kpis_df.signal.isin(list(results_dic_without_df['index'] ))]
+    return kpis_df
+
 
 def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False, normalization = False):
     if normalization:
